package net.yakiboo.yakito.update;

import java.net.URL;
import java.net.HttpURLConnection;
import java.io.*;
import java.net.MalformedURLException;
import java.net.URLConnection;
import javax.swing.JFileChooser;

import net.yakiboo.yakito.utils.Utils;
import net.yakiboo.yakito.utils.Stopwatch;

import java.nio.*;
import java.nio.channels.*;

/**
 * Clase para la descarga de archivos de internet.
 * 
 * @author sgm
 */
public class Downloader {

	private URL url;
	private long sizeInBytes;
	private long bytesDownloaded;
	private File directoryDestiny;
	private File[] partes;
	private int trozosTerminados;

	public Downloader(String urlString, File folder) {
		sizeInBytes = -1;
		bytesDownloaded = -1;
		try {
			directoryDestiny = folder;
			System.out.print(">> Analizando URL... ");
			this.url = new URL(urlString);
			System.out.println("CORRECTA");
		} catch (java.net.MalformedURLException ex01) {
			System.err
					.println(">> ERROR al crear el objeto Downloader. La URL \""
							+ urlString + "\" no es correcta.");
		}
	}

	public long getSizeInBytes() {
		if (sizeInBytes < 0) {
			sizeInBytes = this.calculeSize();
		}
		return sizeInBytes;
	}

	public String getSizeInString() {
		return Utils.sizeToString(getSizeInBytes(), 2);
	}

	/**
	 * Obtiene el nombre del fichero al que hace referencia la URL.
	 * 
	 * @return nombre del fichero.
	 */
	public String getFileName() {
		String urlString = this.url.toString();
		int i = urlString.length() - 1;
		char c;
		while ((c = urlString.charAt(i)) != '/') {
			i--;
		}
		return urlString.substring(i);
	}

	/**
	 * Calcula el tamaño del archivo al que hace referencia el objeto
	 * Downloader.
	 * 
	 * @return tamaño en bytes
	 */
	private long calculeSize() {
		System.out.print(">> Calculando tamaño de archivo de forma rápida... ");
		HttpURLConnection urlc;
		long size = -1;
		try {
			urlc = (HttpURLConnection) url.openConnection();
			size = urlc.getContentLength();
			if (size < 0) {
				System.out.print("ERROR\n>> Calculándolo de forma lenta...");
				InputStream inStream;
				inStream = urlc.getInputStream();
				long len = 0;
				while ((len = inStream.skip(1024)) > 0) {
					size += len;
				}
				inStream.close();
			}
			System.out.println(Utils.sizeToString(size, 2));
			urlc.disconnect();
		} catch (IOException e) {
			System.out.println(">> ERROR Calculando el tamaño del fichero");
		}

		this.sizeInBytes = size;
		return size;
	}

	public void startSimpleDownload(File destiny, boolean checkSize) {
		if (destiny == null) {
			String path = "";
			javax.swing.JFileChooser fc = new javax.swing.JFileChooser();
			fc.setFileSelectionMode(fc.DIRECTORIES_ONLY);
			fc.showOpenDialog(null);
			path = fc.getSelectedFile().getAbsolutePath() + this.getFileName();
			destiny = new File(path);
		}
		if (checkSize) {

			System.out.println(getSizeInString());
		}

		HttpURLConnection urlc;
		InputStream inStream;
		OutputStream outStream;

		try {
			urlc = (HttpURLConnection) url.openConnection();
			inStream = urlc.getInputStream();
			outStream = new FileOutputStream(destiny);
			System.out.println(">> Comenzando descarga de \"" + url + "\"");
			simpleCopyWithoutClosing(inStream, outStream);
			System.out.println(">> Descarga de \"" + url + "\" finalizada.");
			urlc.disconnect();
			inStream.close();
			outStream.close();
		} catch (java.io.IOException ex02) {
			System.err
					.println(">> ERROR de E/S mientras se descargaba el fichero \""
							+ url + "\".");
		}
	}

	private void simpleCopyWithoutClosing(InputStream in, OutputStream out)
			throws IOException {
		byte[] buf = new byte[1024];
		int len, len2 = 0, retardador = 0;
		long readed = 0;
		Stopwatch c = new Stopwatch(), aux = new Stopwatch();
		c.startClock();
		aux.startClock();
		while ((len = in.read(buf)) > 0) {
			if (retardador % 20 != 0) {
				len2 += len;
			}
			retardador++;
			out.write(buf, 0, len);
			readed += len;
			if (retardador % 20 == 0) {
				c.stopClock();
				aux.stopClock();
				// System.out.println(">> Descargando a " +
				// Utils.speedInString(aux.getResult(), len2) + " (" +
				// Utils.speedInString(c.getResult(), readed) +
				// ")\tDescargados " + Utils.sizeToString(readed, 2) + " de " +
				// Utils.sizeToString(sizeInBytes, 2) + "\r");
				aux.startClock();
				len2 = 0;
			}
		}
		// System.out.println(">> Descargando a " +
		// Utils.speedInString(aux.getResult(), len2) + " (" +
		// Utils.speedInString(c.getResult(), readed) + ")\tDescargados " +
		// Utils.sizeToString(readed, 2) + " de " +
		// Utils.sizeToString(sizeInBytes, 2));
		in.close();
		out.close();
	}

	

}
