package net.yakiboo.yakito.utils;

import java.net.URL;

/**
 * Utilidades estáticas varias.
 * 
 * @author Sergio Garcia Mondaray
 */
public class Utils {

	/**
	 * Calcula la velocidad de transferencia, de forma dinámica en B/s, KB/s,
	 * MB/s, etc.
	 * 
	 * @param timeInMiliseconds
	 *            tiempo transcurrido, en milisegundos.
	 * @param sizeInBytes
	 *            bytes transferidos en dicho tiempo.
	 * @return String con el resultado en formato "XXX KiB/s".
	 */
	public static String speedInString(long timeInMiliseconds, long sizeInBytes) {
		if (timeInMiliseconds == 0)
			timeInMiliseconds = 1000;
		long bytesPerSecond = (long) (1000.0 * sizeInBytes)
				/ (timeInMiliseconds);
		return sizeToString(bytesPerSecond, 2) + "/s";
	}

	/**
	 * Calcula la velocidad de transferencia, en KB/s.
	 * 
	 * @param timeInMiliseconds
	 *            tiempo transcurrido, en milisegundos.
	 * @param sizeInBytes
	 *            bytes transferidos en dicho tiempo.
	 * @return velocidad en KB/s.
	 */
	public static double speed(long timeInMiliseconds, long sizeInBytes) {
		double time = (1000.0 * sizeInBytes) / (1024.0 * timeInMiliseconds);
		return time;
	}

	/**
	 * Da formato de B, KiB, MiB, etc. al numero de bytes indicado, truncando al
	 * numero de decimales indicado.
	 * 
	 * @param bytes
	 *            numero a formalizar.
	 * @param ndec
	 *            numero de decimales.
	 * @return String con el tamaño formateado.
	 */
	public static String sizeToString(long bytes, int ndec) {
		String size = " B";
		double aux = bytes;
		if (aux > 1024) {
			aux = aux / 1024.0;
			if (aux > 1024) {
				aux = aux / 1024.0;
				if (aux > 1024) {
					aux = aux / 1024.0;
					if (aux > 1024) {
						aux = aux / 1024.0;
						size = " TB";
					} else {
						size = " GiB";
					}
				} else {
					size = " MiB";
				}
			} else {
				size = " KiB";
			}
		}

		return onlyNDec(aux, ndec) + size;
	}

	private static String onlyNDec(double num, int ndec) {
		String s = String.valueOf(num);
		String aux = "";
		int ndecs = 0, i = 0;
		boolean indec = false;
		while (ndecs <= ndec && i < s.length()) {
			aux += s.charAt(i);
			if (s.charAt(i) == '.') {
				indec = true;
			}
			if (indec) {
				ndecs++;
			}
			i++;
		}
		return aux;
	}

	public static String getNameFromURL(URL url) {
		String urlString = url.toString();
		int i = urlString.length() - 1;
		char c;
		while ((c = urlString.charAt(i)) != '/') {
			i--;
		}
		return urlString.substring(i);
	}

}
